use std::fs::File;
use std::path::PathBuf;
use std::str::FromStr;
use std::time::Duration;

use rodio::{Decoder, OutputStream, Source};
fn main() {
    const URL: &str = "file:///home/plex/Musik/Plex/ｍｏｏｎｗａｔｅｒ.mp3";
    let f = open_file_url(URL).unwrap();
    let reader = std::io::BufReader::new(f);

    // Get an output stream handle to the default physical sound device
    let (_stream, stream_handle) = OutputStream::try_default().unwrap();
    // Decode that sound file into a source
    let source = Decoder::new(reader).unwrap();
    // Play the sound directly on the device
    stream_handle.play_raw(source.convert_samples()).unwrap();
    std::thread::sleep(Duration::from_secs(10)); // should be fine, because tokio says
                                                 // spawn_blocking happens in another thread
}

fn open_file_url(url: &str) -> std::io::Result<File> {
    if !url.starts_with("file://") {
        return Err(std::io::Error::new(std::io::ErrorKind::Unsupported, "bad"));
    }

    let path = url.replacen("file://", "", 1);
    if let Ok(path) = PathBuf::from_str(&path) {
        let f = std::fs::File::open(path)?;
        Ok(f)
    } else {
        Err(std::io::Error::new(
            std::io::ErrorKind::Unsupported,
            "not a path even without file://",
        ))
    }
}
