use std::error::Error;
use std::result::Result;
use std::time::Duration;

use reqwest::header::HeaderMap;
use reqwest::Client;
use rodio::{Decoder, OutputStream, Source};
use stream_download::http::HttpStream;
use stream_download::storage::memory::MemoryStorageProvider;
use stream_download::{Settings, StreamDownload};

#[tokio::main(flavor = "current_thread")]
async fn main() -> Result<(), Box<dyn Error>> {
    const URL: &str = "https://upload.wikimedia.org/wikipedia/commons/4/48/Aadama.mp3";

    let mut headers = HeaderMap::new();
    headers.append("User-Agent", "Beatbär Streaming Demo".parse().unwrap());

    let client = Client::builder().default_headers(headers).build()?;

    let stream = HttpStream::new(client, URL.parse()?).await?;
    let reader =
        StreamDownload::from_stream(stream, MemoryStorageProvider, Settings::default()).await?;

    // now play with rodio, or read it out
    tokio::task::spawn_blocking(move || {
        // Get an output stream handle to the default physical sound device
        let (_stream, stream_handle) = OutputStream::try_default().unwrap();
        // Decode that sound file into a source
        let source = Decoder::new(reader).unwrap();
        // Play the sound directly on the device
        stream_handle.play_raw(source.convert_samples()).unwrap();
        std::thread::sleep(Duration::from_secs(10)); // should be fine, because tokio says
                                                     // spawn_blocking happens in another thread
    })
    .await?;

    Ok(())
}
