use egui::text::LayoutJob;
use egui::{Color32, FontFamily, FontId, Label, TextFormat};

use super::Entry;

#[derive(Clone, Default, PartialEq)]
pub struct Details {
    parent: Entry,
    frame: egui::Frame,
}

impl Details {
    pub fn new(parent: Entry) -> Self {
        let frame = egui::Frame::none();
        Self {
            parent: parent.to_owned(),
            frame,
        }
    }

    pub(crate) fn ui(&self, ui: &mut egui::Ui, ctx: &egui::Context, player: &mut super::Player) {
        ui.label("todo");
    }
}

impl egui::Widget for Details {
    fn ui(self, ui: &mut egui::Ui) -> egui::Response {
        ui.vertical_centered(|ui| {
            let r = ui.add(
                egui::Image::new(self.parent.img())
                    .rounding(5.0)
                    .bg_fill(Color32::DARK_GRAY)
                    .shrink_to_fit()
                    .maintain_aspect_ratio(true),
            );
            let mut job = LayoutJob::default();
            job.append(
                &self.parent.title,
                0.0,
                TextFormat {
                    font_id: FontId::new(14.0, FontFamily::Proportional),
                    ..Default::default()
                },
            );
            r.union(ui.add(Label::new(job)));
            r.union(ui.label(&self.parent.subtitle));
        })
        .response
    }
}

impl std::fmt::Debug for Details {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.debug_struct("Details")
            .field("parent", &self.parent)
            .finish()
    }
}
