use egui::Sense;
use egui_extras::{Column, TableBuilder};
use libpt::log::{debug, warn};

use super::showbox::ShowBox;
use super::Player;

#[derive(Clone, Default, PartialEq)]
pub struct Overview {
    frame: egui::Frame,
}

impl Overview {
    pub fn ui(&self, ui: &mut egui::Ui, ctx: &egui::Context, player: &mut Player) {
        let mut tb = TableBuilder::new(ui);

        let entries_per_line: usize = ctx.screen_rect().width() as usize / 256;

        for _ in 0..entries_per_line {
            tb = tb.column(Column::remainder());
        }

        tb.body(|mut body| {
            for line in player.entries().chunks(entries_per_line) {
                body.row(240.0, |mut row| {
                    for e in line {
                        row.col(|ui| {
                            let shobo = ui.add(ShowBox::new(e));
                            let shobo = shobo.interact(Sense::click());
                            if shobo.clicked() {
                                debug!("showbox \"{:#?}\" was clicked", shobo);
                                warn!("clicking for showbox not defined yet");
                                player.open(e);
                            }
                        });
                    }
                });
            }
        });
    }
}

impl std::fmt::Debug for Overview {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.debug_struct("Overview").finish()
    }
}
